@@ -638,12 +638,11 @@ make_folder_info (CamelExchangeStore *exch, char *name, char *uri,
 	info->name = name;
 	info->uri = new_uri;
 
-#if 0	
 	/* Process the full-path and decode if required */
 	temp = strrchr (path+2, '/');
 	if (temp) {
 		/* info->full_name should not have encoded path */
-		/*info->full_name = camel_url_decode_path (path+2);*/
+		info->full_name = camel_url_decode_path (path+2);
 	} else {
 		/* If there are no sub-directories, decoded(name) will be 
 		   equal to that of path+2.
@@ -651,8 +650,6 @@ make_folder_info (CamelExchangeStore *exch, char *name, char *uri,
 		*/
 		info->full_name = g_strdup (path+2);
 	}
-#endif
-	info->full_name = g_strdup (path+2);
 	info->unread = unread_count;
 
 	if (flags & CAMEL_STUB_FOLDER_NOSELECT)
@@ -668,6 +665,9 @@ make_folder_info (CamelExchangeStore *exch, char *name, char *uri,
 		info->flags |= CAMEL_FOLDER_SUBSCRIBED;
 		d(printf ("MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMmark as subscribed\n"));
 	}
+
+	if (flags & CAMEL_STUB_FOLDER_NOCHILDREN)
+		info->flags |= CAMEL_FOLDER_NOCHILDREN;
 	return info;
 }
 
@@ -684,7 +684,8 @@ postprocess_tree (CamelFolderInfo *info)
 	/* If the node still has children, keep it */
 	if (info->child)
 		return info;
-	info->flags |= CAMEL_FOLDER_NOCHILDREN;
+
+	/* info->flags |= CAMEL_FOLDER_NOCHILDREN; */
 
 	/* If it's a mail folder (not noselect), keep it */
 	if (!(info->flags & CAMEL_FOLDER_NOSELECT))
